# vim: set ts=4 sw=4 et:

%{!?python_sitelib:  %global python_sitelib  %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}

Name:           deluge
Version:        1.3.5
%define pkg_version %{version}
Release:        1.19
Summary:        Bittorrent Client
Source:         http://download.deluge-torrent.org/source/deluge-%{pkg_version}.tar.bz2
Patch1:         deluge-remove_pointless_shebangs.patch
Source99:       %{name}-rpmlintrc
URL:            http://deluge-torrent.org/
Group:          Productivity/Networking/Other
License:        GNU General Public License version 3 (GPL v3)
BuildRoot:      %{_tmppath}/build-%{name}-%{version}
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif
# Core
Requires:       python-twisted python-openssl python-setuptools python-xdg python-chardet python-markupsafe 
Recommends:     python-GeoIP
# Gtk
Requires:       python-notify python-pygame python-gtk xdg-utils
# Web
Requires:       python-mako

Requires:       python-libtorrent-rasterbar >= 0.14.9
BuildRequires:  python-libtorrent-rasterbar >= 0.14.9

BuildRequires:  python-setuptools python-base
BuildRequires:  intltool
BuildRequires:  fdupes
BuildRequires:  update-desktop-files

Provides:       %{name}-plugins = %{version}-%{release}
Provides:       %{name}-torrent = %{version}-%{release}
Obsoletes:      %{name}-unstable < %{version}
Provides:       %{name}-unstable = %{version}-%{release}
Provides:       %{name}-ui-web = %{version}-%{release}
Provides:       %{name}-ui-gtk = %{version}-%{release}
Provides:       %{name}-ui-console = %{version}-%{release}

%py_requires

%description
A more full-featured yet still lightweight bittorrent client for Linux. Has
the ability to automatically resume partial downloads and background to the
system tray.

%prep
%setup -q -n "deluge-%{version}"
%patch1

%build
PREFIX="%{_prefix}" \
%__python ./setup.py build

%install
PREFIX="%{_prefix}" \
%__python ./setup.py install \
     --prefix="%{_prefix}" \
     --root="%{buildroot}" \

LANGFILE=$PWD/deluge.lang
echo -n >"$LANGFILE"
pushd "%{buildroot}%{python_sitelib}/deluge/i18n"
/bin/ls -1 | while read lang; do
     [ -d "$lang" ] || continue
     echo "%lang(${lang}) %{python_sitelib}/deluge/i18n/${lang}" >>"$LANGFILE"
done
popd

rm %{buildroot}%{python_sitelib}/deluge/ui/web/gen_gettext.py*

%suse_update_desktop_file -r deluge Network FileTransfer

%fdupes -s "%{buildroot}%{python_sitelib}"

%clean
%__rm -rf "%{buildroot}"

%files -f deluge.lang
%defattr(-,root,root)
%doc LICENSE README ChangeLog
%{_mandir}/man1/deluge.1%{ext_man}
%{_mandir}/man1/deluged.1%{ext_man}
%{_mandir}/man1/deluge-gtk.1%{ext_man}
%{_mandir}/man1/deluge-web.1%{ext_man}
%{_mandir}/man1/deluge-console.1%{ext_man}
%{python_sitelib}/*
%{_bindir}/*
%{_datadir}/applications/*
%{_datadir}/icons/*
%{_datadir}/pixmaps/*

%changelog
* Tue May 22 2012 pascal.bleser@opensuse.org
- update to 1.3.5:
  * Fix not properly detecting when torrent is at end of queue
  * #2049: Preserve order when moving multiple torrents in the queue
  * Modified fix for #1957, keyerror with non-acsii columns
  * Fix translation of items in Sidebar and Torrent Menu
  * #2052: Fix translation of Progress bar text
  * #2071: Fix KeyError in gtkui when file priority set to value '3'
  * #2064: Fix files treeview height in Create Dialog
  * Fix missing semi-colon in deluge.desktop
  * Disable setting file priorities for seeding torrents
  * Bring MainWindow to front when opening another instance
  * #2050: Fix 'Up Speed' column not sorting
  * Hide unused Infohash button in WebUI
  * Disable unusable items for 'All' in sidebar menu
  * Fix items for translation
  * Fix prefixed space for tab completing commands
  * Fix missing trailing space for command options with tab complete
  * Use (documented) formatdate over format_date_time
* Thu Mar 22 2012 packman@ammler.ch
- update to 1.3.4
  too many changes to list here
  (see http://dev.deluge-torrent.org/wiki/ChangeLog)
* Mon Nov 14 2011 pascal.bleser@opensuse.org
- Requires python-pyxdg -> python-xdg, as that is how the package that ships
  with the distribution is named (the python-pyxdg package has hence been
  obsoleted and removed in the Packman repository)
* Fri Jul 29 2011 packman@ammler.ch
- update to 1.3.3
  * Core
    Properly show the 'Checking Resume Data' state instead of just 7
    [#1788]: Added ability to use XDG_DOWNLOAD_DIR as default download folder
    Fix path error with torrent files prefixed with ' file://' from Firefox
    [#1504]: Fix win32 running deluged as not logged in user via runas or service
    [#890]: If added torrent already exists, append extra trackers to it
    [#1338]: Fix Seeds and Peers totals not updating
    [#1239]: Fix translated Tracker Error text not counted in sidebar Error status
    Fix httpdownloader error with existing filename
    [#1505]: Add libtorrent info to version output
    [#1637] Fix UnicodeDecodeError? from 'deluge-* --help' with non-english languages
    [#1714] Fix handling of backslashes when renaming files/folders
  * GtkUI
    Show the checking icon for torrents in the 'Checking Resume Data' state
    [#1195]: Fix right-click selecting issue when switching between folders and files
    Add F2 key shortcut for renaming filenames in the Files Tab
    Increase max piece size to 16 MiB in create torrent dialog
    [#1475]: Fix save and restore Preferences dialog size from config
    Add search as you type to the torrent view
    [#1456]: Fix no ETA showing with multiple files
    [#1560]: Fix FilesTab? Progress value sorting by int instead of float
    [#1263]: Fix not remembering column widths
    [#948]: New Release Dialog now shows the server version
    Fix peers in PeersTab? showing non-zero download rate when seeding
  * AutoAdd
    [#1861]: Fix AutoAdd? Warning (column number is a boolean)
  * Label
    [#1246]: Fix losing Labels upon restart
  * Execute
    [#1477]: Fix ignore Added events from state file on startup
  * ConsoleUI
    [#1258]: Add support for urls and magnet uris in add command
    [#1801]: Fix unhandled defered error and missing error message upon failed connect
* Wed May 25 2011 packman@ammler.ch
- update to 1.3.2
  * Core:
  * Fix a bug that can occur when upgrading 1.1 config files
  * #1517: Fix isohunt urls not loading
  * Handle redirection when adding a torrent by url
  * GtkUI:
  * #1514: Added Indicator Applet
  * #1494: Add torrent columns Downloaded and Uploaded
  * #1308: Add torrent column Seeds/Peers ratio
  * #1646: Add torrent columns for per torrent upload and download speed limits
  * #690:  Fix renaming folders does not remove old empty folders
  * #1498: Fix double slashes appearing when renaming
  * Add Key Shortcuts for main menu functions
  * WebUI:
  * #1355: Fix slow changing states in webUI
  * #1536: Fix Edit Trackers window not scrolling and not being resizable
  * #1799: Fix Missing textbox for "Move completed" in torrent options
  * #1268: Fix torrent errors not displayed in webui
  * #1333: Fix peer list doesn't update automatically
  * #1537: Fix editing trackers list, trackers have to be reselected
  * ConsoleUI:
  * #755:  Fix can't set listen_ports through console UI
  * #1500: Fix Console crashes on command longer than terminal width
  * #1248: Fix deluge-console unicode support on redirected stdout
  * #1450: Fix trailing white space in paths
  * #1856: Add --sort option to info command
  * #1857: Add seeding_time, active_time and tracker_status to info command
  * Scheduler:
  * #1506: Fix max speed not restored on a yellow->green transition
* Thu Dec  9 2010 pascal.bleser@opensuse.org
- update to 1.3.1:
  * core:
  + #1369: fix non-ascii config folders not working in windows
  * GTK:
  + #1365: fix sidebar not updating show/hide trackers
  + #1247: fix hang on quit
  * WebUI:
  + #1364: fix preferences not saving when the web ui plugin is enabled in classic mode
  + #1377: fix bug when enabling plugins
  + #1370: fix issues with preferences
  + #1312: fix deluge-web using 100%% CPU
* Wed Oct  6 2010 pascal@links2linux.de
- update to 1.3.0
* Wed Mar 31 2010 tkedwards@fastmail.com.au
- update to 1.2.3:
  * Fix libtorrent version compare to use a proper numerical compare instead of string. This fixes a problem where using lt 0.14.10 wouldn't allow Deluge to start.
  * Fix libtorrent 0.15 compatibility
* Sat Mar 20 2010 pascal@links2linux.de
- update to 1.2.2:
  * fix #1109 auto add halting when a torrent with invalid filename
    encoding is in the directory
  * GTK: fix #1162 problem with the queued torrents dialog from not
    properly adding to the add torrent dialog if set to auto add
  * GTK: fix #1172 notify startup complete when adding torrents
    externally
  * GTK: fix issue where the gtkui sometimes won't start if there
    is a stale lock file or socket in the ipc/ directory.
  * Console: fix #1143 deluge-console crashes when tab-completing
    not-existent directory
* Mon Feb 22 2010 pascal.bleser@opensuse.org
- update to 1.2.1
* Thu Jan 14 2010 tkedwards@fastmail.com.au
- Updated for 1.2.0, see http://dev.deluge-torrent.org/wiki/ChangeLog
* Mon Dec 28 2009 tkedwards@fastmail.com.au
- Updated for 1.2.0_rc5, see http://dev.deluge-torrent.org/wiki/ChangeLog
* Mon Nov 23 2009 tkedwards@fastmail.com.au
- Updated for 1.2.0_rc3
- Updated Requires: from the dependencies list at http://dev.deluge-torrent.org/wiki/Installing/Source
* Tue Jan 13 2009 guru@unixtech.be
- scrapped old %%%%changelog entries
- update to 1.1.0
* Sat Dec 13 2008 guru@unixtech.be
- update to 1.0.7:
  * GtkUI: fix #636 not setting the daemon's config directory when using
  - -config= with the UI in classic mode
  * GtkUI: fix some minor bugs in ConnectionManager
  * WebUI: changed all icons from tango to kde-oxygen because of licensing
    issues in debian
  * fix #547 add description to name field per HIG entry 2.1.1.1
  * libtorrent updates
  * point default blocklist url to our server and up interval to 4 days
* Mon Dec  1 2008 guru@unixtech.be
- update to 1.0.6:
  * fix #475: catch unicode decoding errors
  * add an option to not include IP overhead in rate limiting (this is equivalent
    to how 0.5.x behaves)
  * GtkUI: display the proper downloaded value in the statistics tab
